﻿using System;
using System.Configuration;
using System.Data;
using System.Data.SqlClient;
using System.IO;
using System.Web;
using System.Web.Security;

namespace WebApplication
{
    public partial class Account : System.Web.UI.Page
    {
        public String LoginID
        {
            get
            {
                return HttpContext.Current.User.Identity.Name;
            }
        }
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!HttpContext.Current.User.Identity.IsAuthenticated)
                Response.Redirect("~/Login.aspx");
            else
            {
                if (!Page.IsPostBack)
                    BindData();
            }
        }

        protected void BtnLogOut_Click(object sender, EventArgs e)
        {
            FormsAuthentication.SignOut();
            Session.Abandon();

            Response.Redirect("~/Account.aspx");
        }

        protected void BtnUpdate_Click(object sender, EventArgs e)
        {
            using (SqlConnection con = new SqlConnection(ConfigurationManager.ConnectionStrings["DBConnectionString"].ConnectionString))
            {
                using (SqlCommand command = new SqlCommand("USP_LoginDetails_Update", con))
                {
                    if (con.State == ConnectionState.Closed)
                        con.Open();

                    command.CommandType = CommandType.StoredProcedure;
                    command.Parameters.AddWithValue("@LoginID", LoginID);
                    command.Parameters.AddWithValue("@LoginName", TxtEmail.Text.Trim());
                    command.Parameters.AddWithValue("@LoginPassword", TxtPassword.Text.Trim());
                    command.Parameters.AddWithValue("@NotificationEmailAddress", TxtNotificationEmail.Text.Trim());

                    command.ExecuteNonQuery();
                }
            }
        }

        protected void BtnExport_Click(object sender, EventArgs e)
        {
            String FileName = Guid.NewGuid().ToString() + ".csv";
            String FilePath = Server.MapPath("~/DataExport/") + FileName;

            CreateCSVFile(GetUserDetails(), FilePath);
            Response.Redirect("~/DataExport/" + FileName);
        }

        DataTable GetUserDetails()
        {
            using (SqlConnection con = new SqlConnection(ConfigurationManager.ConnectionStrings["DBConnectionString"].ConnectionString))
            {
                using (SqlDataAdapter adapter = new SqlDataAdapter("SELECT * FROM UserDetails", con))
                {
                    using (DataTable userDetails = new DataTable())
                    {
                        adapter.Fill(userDetails);

                        return userDetails;
                    }
                }
            }
        }

        void CreateCSVFile(DataTable dt, string strFilePath)
        {
            using (StreamWriter sw = new StreamWriter(strFilePath, false))
            {
                int iColCount = dt.Columns.Count;
                for (int i = 0; i < iColCount; i++)
                {
                    sw.Write(dt.Columns[i]);
                    if (i < iColCount - 1)
                    {
                        sw.Write(",");
                    }
                }
                sw.Write(sw.NewLine);

                foreach (DataRow dr in dt.Rows)
                {
                    for (int i = 0; i < iColCount; i++)
                    {
                        if (!Convert.IsDBNull(dr[i]))
                        {
                            sw.Write("\"" + dr[i].ToString() + "\"");
                        }
                        if (i < iColCount - 1)
                        {
                            sw.Write(",");
                        }
                    }
                    sw.Write(sw.NewLine);
                }
            }
        }

        void BindData()
        {
            using (SqlConnection con = new SqlConnection(ConfigurationManager.ConnectionStrings["DBConnectionString"].ConnectionString))
            {
                using (SqlDataAdapter adapter = new SqlDataAdapter("SELECT * FROM LoginDetails", con))
                {
                    using (DataTable LoginDetails = new DataTable())
                    {
                        adapter.Fill(LoginDetails);

                        if (LoginDetails != null && LoginDetails.Rows.Count > 0)
                        {
                            TxtEmail.Text = LoginDetails.Rows[0]["LoginName"] as String;
                            TxtPassword.Attributes.Add("value", LoginDetails.Rows[0]["LoginPassword"] as String);
                            TxtNotificationEmail.Text = LoginDetails.Rows[0]["NotificationEmailAddress"] as String;
                        }
                    }
                }
            }

            RptUserDetails.DataSource = GetUserDetails();
            RptUserDetails.DataBind();
        }

        protected void RptUserDetails_ItemCommand(object source, System.Web.UI.WebControls.RepeaterCommandEventArgs e)
        {
            if (e.CommandName.Equals("DeleteUser"))
            {
                String UserId = Convert.ToString(e.CommandArgument);

                if (String.IsNullOrEmpty(UserId))
                    return;

                using (SqlConnection con = new SqlConnection(ConfigurationManager.ConnectionStrings["DBConnectionString"].ConnectionString))
                {
                    using (SqlCommand command = new SqlCommand("Delete From UserDetails WHERE UserId = @UserId", con))
                    {
                        if (con.State == ConnectionState.Closed)
                            con.Open();

                        command.Parameters.AddWithValue("@UserId", UserId);

                        command.ExecuteNonQuery();
                    }
                }
            }

            this.BindData();
        }
    }
}