﻿using System;
using System.Configuration;
using System.Data.SqlClient;
using System.Web.UI;
using System.Data;
using System.Net.Mail;
using System.IO;

namespace WebApplication
{
    public partial class Registration : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                BindData();
            }
        }

        void BindData()
        {
            for (int i = 1; i <= 12; i++)
            {
                DdlCreditCardMonth.Items.Add(i.ToString("00"));
            }

            for (int i = DateTime.Now.Year; i <= DateTime.Now.Year + 15; i++)
            {
                DdlCreditCardYear.Items.Add(i.ToString("00"));
            }
        }

        protected void BtnSubmit_Click(object sender, EventArgs e)
        {
            Model.UserDetails userDetail = new Model.UserDetails();

            userDetail.FirstName = TxtFirstName.Text.Trim();
            userDetail.LastName = TxtLastName.Text.Trim();
            userDetail.PhoneNumber = TxtPhoneNumber.Text.Trim();
            userDetail.EmailAddress = TxtEmailAddress.Text.Trim();
            userDetail.Address = TxtAddress.Text.Trim();
            userDetail.City = TxtCity.Text.Trim();
            userDetail.State = TxtState.Text.Trim();
            userDetail.ZIP = TxtZip.Text.Trim();
            userDetail.CountryCitizenship = TxtCitizenship.Text.Trim();
            userDetail.CollegeUniversity = TxtUniversity.Text.Trim();
            userDetail.IsSkills = ChkSkills.Checked;
            userDetail.IsGovernmentExportRegulation = ChkGovernmentExportRegulation.Checked;
            userDetail.IsImageRelease = ChkImageRelease.Checked;
            userDetail.CreditCardNumber = TxtCreditCardNumber.Text.Trim();
            userDetail.CreditCardName = TxtCreditCardName.Text.Trim();
            userDetail.CreditCardCSV = TxtCreditCardCSV.Text.Trim();
            userDetail.CreditCardExpMonth = DdlCreditCardMonth.SelectedItem.Value;
            userDetail.CreditCardExpYear = DdlCreditCardYear.SelectedItem.Value;
            userDetail.Participate1FirstName = TxtParticipate1FirstName.Text.Trim();
            userDetail.Participate1LastName = TxtParticipate1LastName.Text.Trim();
            userDetail.Participate2FirstName = TxtParticipate2FirstName.Text.Trim();
            userDetail.Participate2LastName = TxtParticipate2LastName.Text.Trim();

            this.SaveData(userDetail);
        }

        void SaveData(Model.UserDetails userDetail)
        {
            try
            {
                using (SqlConnection con = new SqlConnection(ConfigurationManager.ConnectionStrings["DBConnectionString"].ConnectionString))
                {
                    using (SqlCommand command = new SqlCommand("USP_UserDetails_Create", con))
                    {
                        if (con.State == ConnectionState.Closed)
                            con.Open();

                        command.CommandType = CommandType.StoredProcedure;
                        command.Parameters.AddWithValue("@FirstName", userDetail.FirstName);
                        command.Parameters.AddWithValue("@LastName", userDetail.LastName);
                        command.Parameters.AddWithValue("@PhoneNumber", userDetail.PhoneNumber);
                        command.Parameters.AddWithValue("@EmailAddress", userDetail.EmailAddress);
                        command.Parameters.AddWithValue("@Address", userDetail.Address);
                        command.Parameters.AddWithValue("@City", userDetail.City);
                        command.Parameters.AddWithValue("@State", userDetail.State);
                        command.Parameters.AddWithValue("@ZIP", userDetail.ZIP);
                        command.Parameters.AddWithValue("@CountryCitizenship", userDetail.CountryCitizenship);
                        command.Parameters.AddWithValue("@CollegeUniversity", userDetail.CollegeUniversity);
                        command.Parameters.AddWithValue("@IsSkills", userDetail.IsSkills);
                        command.Parameters.AddWithValue("@IsGovernmentExportRegulation", userDetail.IsGovernmentExportRegulation);
                        command.Parameters.AddWithValue("@IsImageRelease", userDetail.IsImageRelease);
                        command.Parameters.AddWithValue("@CreditCardNumber", userDetail.CreditCardNumber);
                        command.Parameters.AddWithValue("@CreditCardName", userDetail.CreditCardName);
                        command.Parameters.AddWithValue("@CreditCardCSV", userDetail.CreditCardCSV);
                        command.Parameters.AddWithValue("@CreditCardExpMonth", userDetail.CreditCardExpMonth);
                        command.Parameters.AddWithValue("@CreditCardExpYear", userDetail.CreditCardExpYear);
                        command.Parameters.AddWithValue("@Participate1FirstName", userDetail.Participate1FirstName);
                        command.Parameters.AddWithValue("@Participate1LastName", userDetail.Participate1LastName);
                        command.Parameters.AddWithValue("@Participate2FirstName", userDetail.Participate2FirstName);
                        command.Parameters.AddWithValue("@Participate2LastName", userDetail.Participate2LastName);

                        command.ExecuteNonQuery();

                        this.SendNewRegistrationNotification(userDetail);

                        Message.InnerHtml = "<span class='text-success'>Data saved successfully</span>";
                    }
                }
            }
            catch (Exception ex)
            {
                Message.InnerHtml = "<span class='text-warning'>Error occured shile saving the data.  See the error details : <br/>" + ex.Message + "</span>";
            }
        }

        void SendNewRegistrationNotification(Model.UserDetails userDetail)
        {
            using (SqlConnection con = new SqlConnection(ConfigurationManager.ConnectionStrings["DBConnectionString"].ConnectionString))
            {
                using (SqlDataAdapter adapter = new SqlDataAdapter("SELECT * FROM LoginDetails", con))
                {
                    using (DataTable LoginDetails = new DataTable())
                    {
                        adapter.Fill(LoginDetails);

                        if (LoginDetails != null && LoginDetails.Rows.Count > 0)
                        {
                            String Email = LoginDetails.Rows[0]["NotificationEmailAddress"] as String;

                            if (String.IsNullOrEmpty(Email))
                                return;

                            this.SendEmail(Email, userDetail);
                        }
                    }
                }
            }
        }

        void SendEmail(String Email, Model.UserDetails userDetail)
        {
            using (SmtpClient smtpClient = new SmtpClient("smtp.sdnthrowdown.com", 587))
            {
                smtpClient.Credentials = new System.Net.NetworkCredential("postmaster@sdnthrowdown.com", "pass123!@#");
                smtpClient.UseDefaultCredentials = true;
                smtpClient.DeliveryMethod = SmtpDeliveryMethod.Network;
               // smtpClient.EnableSsl = false;   

                using (MailMessage mail = new MailMessage())
                {
                    String filePath = Server.MapPath("~/Template/NewUserMailBody.txt");
                    String mailBody = String.Format(GetTemplate(filePath), userDetail.FirstName, userDetail.LastName, userDetail.PhoneNumber, userDetail.EmailAddress, userDetail.CollegeUniversity);

                    mail.From = new MailAddress("postmaster@sdnthrowdown.com", "Postmaster SDNThrowdown");
                    mail.To.Add(new MailAddress("postmaster@sdnthrowdown.com"));
                    
                    mail.IsBodyHtml = true;

                    mail.Subject = "New User Register";
                    mail.Body = mailBody;

                    smtpClient.Send(mail);
                }
            }
        }

        string GetTemplate(String filePath)
        {
            using (StreamReader reader = new StreamReader(filePath))
            {
                return reader.ReadToEnd();
            }
        }
    }
}